/**
 * RSS methods.
 * 
 * @author    Andy Frank
 * @creation  27 Dec 04
 */

////////////////////////////////////////////////////////////////
// Global
////////////////////////////////////////////////////////////////

var checkInProgress = false;
var cancelCheck = false;

////////////////////////////////////////////////////////////////
// Check feeds
////////////////////////////////////////////////////////////////

function doCheckFeeds()
{
  // Bail out if check already in progress
  if (checkInProgress) return;
  if (model.size() > 0) 
  {
    checkInProgress = true;
    var elem = document.getElementById("busyAnimation");
    elem.style.visibility = "visible";
    precheckFeed(0);
  }
}

function doCancelCheckFeeds()
{
  if (checkInProgress) cancelCheck = true;
}

function precheckFeed(index)
{
  var elem = document.getElementById("busyCounter");
  elem.value = "(" + index + " of " + model.size() + ")";
    
  var feed = model.get(index);
  feed.error = ERROR_OK;
    
  var xmlhttp = new XMLHttpRequest();    
  xmlhttp.open("get", feed.url);
  xmlhttp.setRequestHeader("User-Agent", "Mozilla/5.0 NewsFox/0.2");
  xmlhttp.overrideMimeType("application/xml");
  // TODO: do error handling
  // xmlhttp.onerror = foo;
  xmlhttp.onload = function() { checkFeed(index, xmlhttp.responseXML); }
  xmlhttp.send(null);    
}

function checkFeed(index, xml)
{
  try
  {
    var feed = model.get(index);    
    if (!feed.loaded)
    {
      loadFeed(feed);
      feed.loaded = true;
    }
    
    var parser = new Parser(xml);
    if (parser.title != null) 
      feed.defaultName = parser.title;
                
    for (var i=0; i<parser.items.length; i++)
    {
      var item = parser.items[i];
      if (doesArticleExist(feed, item.link)) continue;
      
      var art = new Article();
      art.title = item.title;
      art.link = item.link;
      art.date = item.pubDate;
      art.body = item.content;
      art.read = false;
      art.flag = false;
      
      if (art.date == "") art.date = new Date();
      if (art.title == "") art.title = formatDate(art.date);      
          
      feed.add(art);
    }
    
    feed.sort();
    saveFeed(feed);
  }    
  catch (err) 
  { 
    feed.error = err;
    feed.error += "<p><a href='" + feed.url + "'>" + feed.url + "</a>";    
  }
  
  // Update FeedTree
  var tree = document.getElementById("feedTree");
  tree.treeBoxObject.invalidateRow(index);  
  
  if (!cancelCheck && index < model.size()-1)
  {
    // Check next feed
    precheckFeed(index+1);
  }
  else
  {
    // We're done!  
    var elem = document.getElementById("busyAnimation");
    elem.style.visibility = "hidden";
    checkInProgress = false;
    cancelCheck = false;
    feedSelected();    
  }
}

////////////////////////////////////////////////////////////////
// Util
////////////////////////////////////////////////////////////////

/**
 * Return true if this article already exists.  
 * We assume that every article has a unique link.
 */
function doesArticleExist(feed, link)
{
  for (var i=0; i<feed.size(); i++)
    if (feed.get(i).link == link) 
      return true;
  return false;
}

